type AddressEvents = HashMap<Address, BTreeMap<(Option<B256>, usize), Vec<Event>>>;Expand description
Address-scoped events keyed by signature and indexed input count; anonymous events have no signature.
Aliased Type
struct AddressEvents { /* private fields */ }Layout
Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.
Size: 40 bytes